==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/openshift/api/model/GitHubWebHookCauseFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import javax.validation.Valid;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;

public interface GitHubWebHookCauseFluent<A extends GitHubWebHookCauseFluent<A>> extends Fluent<A>{


    public SourceRevision getRevision();
    public A withRevision(SourceRevision revision);
    public GitHubWebHookCauseFluent.RevisionNested<A> withNewRevision();
    public GitHubWebHookCauseFluent.RevisionNested<A> withNewRevisionLike(SourceRevision item);
    public GitHubWebHookCauseFluent.RevisionNested<A> editRevision();
    public GitHubWebHookCauseFluent.RevisionNested<A> editOrNewRevision();
    public GitHubWebHookCauseFluent.RevisionNested<A> editOrNewRevisionLike(SourceRevision item);
    public String getSecret();
    public A withSecret(String secret);

    public interface RevisionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SourceRevisionFluent<GitHubWebHookCauseFluent.RevisionNested<N>>{

        
    public N and();    public N endRevision();
}


}

==> kubernetes-model-4.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/GitHubWebHookCauseFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface GitHubWebHookCauseFluent<A extends GitHubWebHookCauseFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRevision instead.
 * @return The buildable object.
 */
@Deprecated public SourceRevision getRevision();
    public SourceRevision buildRevision();
    public A withRevision(SourceRevision revision);
    public Boolean hasRevision();
    public GitHubWebHookCauseFluent.RevisionNested<A> withNewRevision();
    public GitHubWebHookCauseFluent.RevisionNested<A> withNewRevisionLike(SourceRevision item);
    public GitHubWebHookCauseFluent.RevisionNested<A> editRevision();
    public GitHubWebHookCauseFluent.RevisionNested<A> editOrNewRevision();
    public GitHubWebHookCauseFluent.RevisionNested<A> editOrNewRevisionLike(SourceRevision item);
    public String getSecret();
    public A withSecret(String secret);
    public Boolean hasSecret();
    public A withNewSecret(String arg1);
    public A withNewSecret(StringBuilder arg1);
    public A withNewSecret(StringBuffer arg1);

    public interface RevisionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SourceRevisionFluent<GitHubWebHookCauseFluent.RevisionNested<N>>{

        
    public N and();    public N endRevision();
}


}
